@@ -52,7 +52,7 @@ dialog_response_cb (GtkDialog *dialog,
 		g_object_unref (file);
 	}
 	else
-		fr_window_stop_batch (window);
+		fr_window_batch_stop (window);
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
@@ -93,7 +93,7 @@ dlg_batch_add_files (FrWindow *window,
 					    NULL);
 	fr_new_archive_dialog_set_files_to_add (FR_NEW_ARCHIVE_DIALOG (dialog), file_list);
 
-	g_signal_connect (dialog,
+	g_signal_connect (GTK_DIALOG (dialog),
 			  "response",
 			  G_CALLBACK (dialog_response_cb),
 			  window);
