@@ -51,7 +51,7 @@ destroy_cb (GtkWidget  *widget,
 
 /* called when the dialog is dismissed. */
 static void
-response_cb (GtkWidget  *widget,
+response_cb (GtkDialog  *widget,
 			int         response_id,
 			DialogData *data)
 {
@@ -96,7 +96,7 @@ response_cb (GtkWidget  *widget,
 
 
 static void
-entry_changed_cb (GtkWidget  *widget,
+entry_changed_cb (GtkEditable *widget,
 		  DialogData *data)
 {
 	if (! gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->d_files_radio)))
@@ -117,11 +117,7 @@ dlg_delete__common (FrWindow *window,
 	data->window = window;
 	data->selected_files = selected_files;
 
-	data->builder = _gtk_builder_new_from_resource ("delete.ui");
-	if (data->builder == NULL) {
-		g_free (data);
-		return;
-	}
+	data->builder = gtk_builder_new_from_resource (FILE_ROLLER_RESOURCE_UI_PATH "delete.ui");
 
 	/* Get the widgets. */
 
@@ -137,7 +133,7 @@ dlg_delete__common (FrWindow *window,
 				NULL);
 
 	ok_button = gtk_dialog_get_widget_for_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK);
-	gtk_style_context_add_class (gtk_widget_get_style_context (ok_button), GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
+	gtk_style_context_add_class (gtk_widget_get_style_context (ok_button), "destructive-action");
 
 	delete_box = _gtk_builder_get_widget (data->builder, "delete_box");
 
@@ -160,23 +156,23 @@ dlg_delete__common (FrWindow *window,
 
 	/* Set the signals handlers. */
 
-	g_signal_connect (G_OBJECT (data->dialog),
+	g_signal_connect (GTK_DIALOG (data->dialog),
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->dialog),
+	g_signal_connect (GTK_DIALOG (data->dialog),
 			  "response",
 			  G_CALLBACK (response_cb),
 			  data);
-//	g_signal_connect_swapped (G_OBJECT (cancel_button),
+//	g_signal_connect_swapped (GTK_BUTTON (cancel_button),
 //				  "clicked",
 //				  G_CALLBACK (gtk_widget_destroy),
 //				  G_OBJECT (data->dialog));
-//	g_signal_connect (G_OBJECT (ok_button),
+//	g_signal_connect (GTK_BUTTON (ok_button),
 //			  "clicked",
 //			  G_CALLBACK (ok_clicked_cb),
 //			  data);
-	g_signal_connect (G_OBJECT (data->d_files_entry),
+	g_signal_connect (GTK_ENTRY (data->d_files_entry),
 			  "changed",
 			  G_CALLBACK (entry_changed_cb),
 			  data);
@@ -192,7 +188,7 @@ dlg_delete (GtkWidget *widget,
 {
 	FrWindow *window = callback_data;
 	dlg_delete__common (window,
-			    fr_window_get_file_list_selection (window, TRUE, NULL));
+			    fr_window_get_file_list_selection (window, TRUE, FALSE, NULL));
 }
 
 
