@@ -42,6 +42,8 @@ typedef struct {
 	GtkWidget    *dialog;
 	GtkBuilder   *builder;
 	gboolean      extract_clicked;
+	gboolean      do_not_extract;
+	GFile        *destination;
 } DialogData;
 
 
@@ -57,43 +59,36 @@ file_selector_destroy_cb (GtkWidget  *widget,
 	_g_string_list_free (data->selected_files);
 	g_free (data->base_dir_for_selection);
 	g_object_unref (data->settings);
+	g_clear_object (&data->destination);
 	g_free (data);
 }
 
+static void extract_cb_possibly_try_to_create_destination_directory (DialogData *data);
+static void extract_cb_check_whether_preparing_destination_failed (DialogData *data);
+static void extract_cb_check_permissions (DialogData *data);
+static void extract_cb_start_extracting (DialogData *data);
+static void create_destination_response_cb (GtkDialog *dialog, int response, DialogData *data);
 
-static int
-extract_cb (GtkWidget   *w,
+static void
+extract_cb (GtkDialog   *dialog,
 	    DialogData  *data)
 {
-	FrWindow   *window = data->window;
-	gboolean    do_not_extract = FALSE;
-	GFile      *destination;
-	gboolean    skip_newer;
-	gboolean    selected_files;
-	gboolean    pattern_files;
-	gboolean    junk_paths;
-	GList      *file_list;
-	char       *base_dir = NULL;
-	GError     *error = NULL;
-
 	data->extract_clicked = TRUE;
 
 	/* collect extraction options. */
 
-	destination = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (data->dialog));
+	data->destination = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (data->dialog));
 
 	/* check directory existence. */
 
-	if (! _g_file_query_is_dir (destination)) {
+	if (! _g_file_query_is_dir (data->destination)) {
 		if (! ForceDirectoryCreation) {
 			GtkWidget *d;
-			int        r;
-			char      *folder_name;
-			char      *msg;
+			g_autofree char *folder_name;
+			g_autofree char *msg;
 
-			folder_name = _g_file_get_display_basename (destination);
+			folder_name = _g_file_get_display_basename (data->destination);
 			msg = g_strdup_printf (_("Destination folder “%s” does not exist.\n\nDo you want to create it?"), folder_name);
-			g_free (folder_name);
 
 			d = _gtk_message_dialog_new (GTK_WINDOW (data->dialog),
 						     GTK_DIALOG_MODAL,
@@ -104,76 +99,125 @@ extract_cb (GtkWidget   *w,
 						     NULL);
 
 			gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
-			r = gtk_dialog_run (GTK_DIALOG (d));
-			gtk_widget_destroy (GTK_WIDGET (d));
-
-			g_free (msg);
-
-			if (r != GTK_RESPONSE_YES)
-				do_not_extract = TRUE;
+			g_signal_connect (GTK_MESSAGE_DIALOG (d), "response", G_CALLBACK (create_destination_response_cb), data);
+			gtk_widget_show (d);
+		} else {
+			extract_cb_possibly_try_to_create_destination_directory (data);
 		}
+	} else {
+		extract_cb_check_whether_preparing_destination_failed (data);
+	}
+}
 
-		if (! do_not_extract && ! _g_file_make_directory_tree (destination, 0755, &error)) {
-			GtkWidget  *d;
 
-			d = _gtk_error_dialog_new (GTK_WINDOW (window),
-						   GTK_DIALOG_DESTROY_WITH_PARENT,
-						   NULL,
-						   _("Extraction not performed"),
-						   _("Could not create the destination folder: %s."),
-						   error->message);
-			gtk_dialog_run (GTK_DIALOG (d));
-			gtk_widget_destroy (GTK_WIDGET (d));
+static void
+create_destination_response_cb (GtkDialog    *dialog,
+		      int           response,
+		      DialogData   *data)
+{
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 
-			g_error_free (error);
-
-			return FALSE;
-		}
+	if (response != GTK_RESPONSE_YES) {
+		data->do_not_extract = TRUE;
 	}
 
-	if (do_not_extract) {
+	extract_cb_possibly_try_to_create_destination_directory (data);
+}
+
+
+static void
+extract_cb_possibly_try_to_create_destination_directory (DialogData  *data)
+{
+	g_autofree GError *error = NULL;
+	if (! data->do_not_extract && ! _g_file_make_directory_tree (data->destination, 0755, &error)) {
+		GtkWidget  *d;
+
+		d = _gtk_error_dialog_new (GTK_WINDOW (data->window),
+					   GTK_DIALOG_DESTROY_WITH_PARENT,
+					   NULL,
+					   _("Extraction not performed"),
+					   _("Could not create the destination folder: %s."),
+					   error->message);
+		g_signal_connect (GTK_MESSAGE_DIALOG (d), "response", G_CALLBACK (gtk_widget_destroy), NULL);
+		gtk_widget_show (d);
+	} else {
+		extract_cb_check_whether_preparing_destination_failed (data);
+	}
+}
+
+
+static void
+extraction_not_performed_cb (GtkDialog    *dialog,
+		      int           response,
+		      DialogData   *data)
+{
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
+	if (fr_window_is_batch_mode (data->window)) {
+		gtk_widget_destroy (data->dialog);
+	}
+}
+
+
+static void
+extract_cb_check_whether_preparing_destination_failed (DialogData  *data)
+{
+	if (data->do_not_extract) {
 		GtkWidget *d;
 
-		d = _gtk_message_dialog_new (GTK_WINDOW (window),
+		d = _gtk_message_dialog_new (GTK_WINDOW (data->window),
 					     GTK_DIALOG_DESTROY_WITH_PARENT,
 					     _("Extraction not performed"),
 					     NULL,
 					     _GTK_LABEL_CLOSE, GTK_RESPONSE_OK,
 					     NULL);
 		gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_OK);
-		gtk_dialog_run (GTK_DIALOG (d));
-		gtk_widget_destroy (GTK_WIDGET (d));
-
-		if (fr_window_is_batch_mode (data->window))
-			gtk_widget_destroy (data->dialog);
-
-		return FALSE;
+		g_signal_connect (GTK_MESSAGE_DIALOG (d), "response", G_CALLBACK (extraction_not_performed_cb), data);
+		gtk_widget_show (d);
+	} else {
+		extract_cb_check_permissions (data);
 	}
+}
 
+
+static void
+extract_cb_check_permissions (DialogData  *data)
+{
 	/* check extraction directory permissions. */
 
-	if (_g_file_query_is_dir (destination)
-	    && ! _g_file_check_permissions (destination, R_OK | W_OK))
+	if (_g_file_query_is_dir (data->destination)
+	    && ! _g_file_check_permissions (data->destination, R_OK | W_OK))
 	{
 		GtkWidget *d;
-		char      *utf8_path;
+		g_autofree char *utf8_path;
 
-		utf8_path = _g_file_get_display_basename (destination);
+		utf8_path = _g_file_get_display_basename (data->destination);
 
-		d = _gtk_error_dialog_new (GTK_WINDOW (window),
+		d = _gtk_error_dialog_new (GTK_WINDOW (data->window),
 					   GTK_DIALOG_DESTROY_WITH_PARENT,
 					   NULL,
 					   _("Extraction not performed"),
 					   _("You don’t have the right permissions to extract archives in the folder “%s”"),
 					   utf8_path);
-		gtk_dialog_run (GTK_DIALOG (d));
-		gtk_widget_destroy (GTK_WIDGET (d));
-
-		g_free (utf8_path);
-		g_object_unref (destination);
-
-		return FALSE;
+		g_signal_connect (GTK_MESSAGE_DIALOG (d), "response", G_CALLBACK (gtk_widget_destroy), NULL);
+		gtk_widget_show (d);
+	} else {
+		extract_cb_start_extracting (data);
 	}
+}
+
+
+static void
+extract_cb_start_extracting (DialogData *data)
+{
+	FrWindow   *window = data->window;
+	GFile      *destination = data->destination;
+	gboolean    skip_newer;
+	gboolean    selected_files;
+	gboolean    pattern_files;
+	gboolean    junk_paths;
+	GList      *file_list;
+	char       *base_dir;
 
 	fr_window_set_extract_default_dir (window, destination);
 
@@ -202,8 +246,7 @@ extract_cb (GtkWidget   *w,
 		file_list = fr_window_get_file_list_pattern (window, pattern);
 		if (file_list == NULL) {
 			gtk_widget_destroy (data->dialog);
-			g_object_unref (destination);
-			return FALSE;
+			return;
 		}
 	}
 
@@ -216,6 +259,7 @@ extract_cb (GtkWidget   *w,
 
 	/* close the dialog. */
 
+	data->destination = NULL; /* do not free when destroying the dialog. */
 	gtk_widget_destroy (data->dialog);
 
 	/* extract ! */
@@ -229,32 +273,26 @@ extract_cb (GtkWidget   *w,
 						junk_paths);
 
 	_g_string_list_free (file_list);
-	g_object_unref (destination);
 	g_free (base_dir);
-
-	return TRUE;
+	g_object_unref (destination);
 }
 
 
-static int
-file_selector_response_cb (GtkWidget    *widget,
+static void
+file_selector_response_cb (GtkDialog    *dialog,
 		      int           response,
 		      DialogData   *data)
 {
 	if ((response == GTK_RESPONSE_CANCEL) || (response == GTK_RESPONSE_DELETE_EVENT)) {
 		gtk_widget_destroy (data->dialog);
-		return TRUE;
+	} else if (response == GTK_RESPONSE_OK) {
+		extract_cb (dialog, data);
 	}
-
-	if (response == GTK_RESPONSE_OK)
-		return extract_cb (widget, data);
-
-	return FALSE;
 }
 
 
 static void
-files_entry_changed_cb (GtkWidget  *widget,
+files_entry_changed_cb (GtkEditable  *widget,
 			DialogData *data)
 {
 	if (! gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("file_pattern_radiobutton"))))
@@ -275,6 +313,8 @@ dlg_extract__common (FrWindow *window,
 	data->selected_files = selected_files;
 	data->base_dir_for_selection = base_dir_for_selection;
 	data->extract_clicked = FALSE;
+	data->do_not_extract = FALSE;
+	data->destination = NULL;
 
 	data->dialog = gtk_file_chooser_dialog_new (C_("Window title", "Extract"),
 						    GTK_WINDOW (data->window),
@@ -289,9 +329,7 @@ dlg_extract__common (FrWindow *window,
 	gtk_file_chooser_set_create_folders (GTK_FILE_CHOOSER (data->dialog), TRUE);
 	gtk_dialog_set_default_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK);
 
-	data->builder = _gtk_builder_new_from_resource ("extract-dialog-options.ui");
-	if (data->builder == NULL)
-		return;
+	data->builder = gtk_builder_new_from_resource (FILE_ROLLER_RESOURCE_UI_PATH "extract-dialog-options.ui");
 	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (data->dialog), GET_WIDGET ("extra_widget"));
 
 	/* Set widgets data. */
@@ -310,15 +348,15 @@ dlg_extract__common (FrWindow *window,
 
 	/* Set the signals handlers. */
 
-	g_signal_connect (G_OBJECT (data->dialog),
+	g_signal_connect (GTK_DIALOG (data->dialog),
 			  "destroy",
 			  G_CALLBACK (file_selector_destroy_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->dialog),
+	g_signal_connect (GTK_DIALOG (data->dialog),
 			  "response",
 			  G_CALLBACK (file_selector_response_cb),
 			  data);
-	g_signal_connect (G_OBJECT (GET_WIDGET ("file_pattern_entry")),
+	g_signal_connect (GTK_ENTRY (GET_WIDGET("file_pattern_entry")),
 			  "changed",
 			  G_CALLBACK (files_entry_changed_cb),
 			  data);
