@@ -50,7 +50,7 @@ destroy_cb (GtkWidget  *widget,
 
 
 static void
-response_cb (GtkWidget  *dialog,
+response_cb (GtkDialog  *dialog,
 	     int         response_id,
 	     DialogData *data)
 {
@@ -81,11 +81,7 @@ dlg_password (GtkWidget *widget,
 
 	data = g_new0 (DialogData, 1);
 	data->window = window;
-	data->builder = _gtk_builder_new_from_resource ("password.ui");
-	if (data->builder == NULL) {
-		g_free (data);
-		return;
-	}
+	data->builder = gtk_builder_new_from_resource (FILE_ROLLER_RESOURCE_UI_PATH "password.ui");
 
 	/* Set widgets data. */
 
@@ -103,7 +99,7 @@ dlg_password (GtkWidget *widget,
 				NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK);
 	gtk_style_context_add_class (gtk_widget_get_style_context (gtk_dialog_get_widget_for_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK)),
-				     GTK_STYLE_CLASS_SUGGESTED_ACTION);
+				     "suggested-action");
 
 	basename = _g_file_get_display_basename (fr_archive_get_file (window->archive));
 	title = g_strdup_printf (_("Enter a password for “%s”"), basename);
@@ -125,11 +121,11 @@ dlg_password (GtkWidget *widget,
 
 	/* Set the signals handlers. */
 
-	g_signal_connect ((data->dialog),
+	g_signal_connect (GTK_DIALOG (data->dialog),
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
-	g_signal_connect ((data->dialog),
+	g_signal_connect (GTK_DIALOG (data->dialog),
 			  "response",
 			  G_CALLBACK (response_cb),
 			  data);
