@@ -29,9 +29,6 @@
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
 #include <handy.h>
-#ifdef ENABLE_NOTIFICATION
-#  include <libnotify/notify.h>
-#endif
 #include "file-utils.h"
 #include "fr-application.h"
 #include "fr-application-menu.h"
@@ -103,11 +100,37 @@ static const GOptionEntry options[] = {
 };
 
 
+static void
+action_open_archive (GSimpleAction      *action,
+		     GVariant           *value,
+		     gpointer            user_data)
+{
+	g_autoptr(GFile)  saved_file;
+	GtkWidget        *new_window;
+
+	saved_file = g_file_new_for_path (g_variant_get_string (value, NULL));
+	new_window = fr_window_new ();
+	gtk_widget_show (new_window);
+	fr_window_archive_open (FR_WINDOW (new_window),
+				saved_file,
+				GTK_WINDOW (new_window));
+}
+
+
+static GActionEntry entries[] = {
+	{
+		.name = "open-archive",
+		.activate = action_open_archive,
+		.parameter_type = "s",
+	},
+};
+
+
 /* -- service -- */
 
 
 static void
-window_ready_cb (GtkWidget *widget,
+window_ready_cb (FrWindow *window,
 		 GError    *error,
 		 gpointer   user_data)
 {
@@ -122,10 +145,10 @@ window_ready_cb (GtkWidget *widget,
 }
 
 
-static gboolean
+static void
 window_progress_cb (FrWindow *window,
 		    double    fraction,
-		    char     *details,
+		    const char *details,
 		    gpointer  user_data)
 {
 	GDBusConnection *connection = user_data;
@@ -140,7 +163,7 @@ window_progress_cb (FrWindow *window,
 						      details),
 				       NULL);
 
-	return TRUE;
+	return;
 }
 
 
@@ -154,7 +177,7 @@ handle_method_call (GDBusConnection       *connection,
 		    GDBusMethodInvocation *invocation,
 		    gpointer               user_data)
 {
-	update_registered_archives_capabilities ();
+	fr_update_registered_archives_capabilities ();
 
 	if (g_strcmp0 (method_name, "GetSupportedTypes") == 0) {
 		char *action;
@@ -221,8 +244,8 @@ handle_method_call (GDBusConnection       *connection,
 		window = fr_window_new ();
 		fr_window_use_progress_dialog (FR_WINDOW (window), use_progress_dialog);
 
-		g_signal_connect (window, "progress", G_CALLBACK (window_progress_cb), connection);
-		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
+		g_signal_connect (FR_WINDOW (window), "progress", G_CALLBACK (window_progress_cb), connection);
+		g_signal_connect (FR_WINDOW (window), "ready", G_CALLBACK (window_ready_cb), invocation);
 
 		fr_window_batch_new (FR_WINDOW (window), _("Compress"));
 		fr_window_batch__add_files (FR_WINDOW (window), file, file_list);
@@ -239,26 +262,28 @@ handle_method_call (GDBusConnection       *connection,
 		gboolean    use_progress_dialog;
 		int         i;
 		GList      *file_list = NULL;
-		GFile      *destination;
+		GFile      *destination = NULL;
 		GtkWidget  *window;
 
 		g_variant_get (parameters, "(^assb)", &files, &destination_uri, &use_progress_dialog);
 
 		if ((destination_uri != NULL) && (strcmp (destination_uri, "") != 0))
 			destination = g_file_new_for_uri (destination_uri);
-		else
-			destination = g_file_get_parent (G_FILE (file_list->data));
 
 		for (i = 0; files[i] != NULL; i++)
 			file_list = g_list_prepend (file_list, g_file_new_for_uri (files[i]));
 		file_list = g_list_reverse (file_list);
 
+		if (destination == NULL && file_list != NULL) {
+			destination = g_file_get_parent (G_FILE (file_list->data));
+		}
+
 		window = fr_window_new ();
 		fr_window_use_progress_dialog (FR_WINDOW (window), use_progress_dialog);
 		fr_window_set_default_dir (FR_WINDOW (window), destination, TRUE);
 
-		g_signal_connect (window, "progress", G_CALLBACK (window_progress_cb), connection);
-		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
+		g_signal_connect (FR_WINDOW (window), "progress", G_CALLBACK (window_progress_cb), connection);
+		g_signal_connect (FR_WINDOW (window), "ready", G_CALLBACK (window_ready_cb), invocation);
 
 		fr_window_batch_new (FR_WINDOW (window), _("Compress"));
 		fr_window_batch__add_files (FR_WINDOW (window), NULL, file_list);
@@ -284,7 +309,7 @@ handle_method_call (GDBusConnection       *connection,
 
 		window = fr_window_new ();
 		fr_window_use_progress_dialog (FR_WINDOW (window), use_progress_dialog);
-		if ((destination_uri != NULL) & (strcmp (destination_uri, "") != 0)) {
+		if ((destination_uri != NULL) && (strcmp (destination_uri, "") != 0)) {
 			GFile *file;
 
 			file = g_file_new_for_uri (destination_uri);
@@ -293,8 +318,8 @@ handle_method_call (GDBusConnection       *connection,
 			g_object_unref (file);
 		}
 
-		g_signal_connect (window, "progress", G_CALLBACK (window_progress_cb), connection);
-		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
+		g_signal_connect (FR_WINDOW (window), "progress", G_CALLBACK (window_progress_cb), connection);
+		g_signal_connect (FR_WINDOW (window), "ready", G_CALLBACK (window_ready_cb), invocation);
 
 		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract archive"));
 		fr_window_batch__extract (FR_WINDOW (window), archive, destination, use_progress_dialog);
@@ -319,8 +344,8 @@ handle_method_call (GDBusConnection       *connection,
 		window = fr_window_new ();
 		fr_window_use_progress_dialog (FR_WINDOW (window), use_progress_dialog);
 
-		g_signal_connect (window, "progress", G_CALLBACK (window_progress_cb), connection);
-		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
+		g_signal_connect (FR_WINDOW (window), "progress", G_CALLBACK (window_progress_cb), connection);
+		g_signal_connect (FR_WINDOW (window), "ready", G_CALLBACK (window_ready_cb), invocation);
 
 		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract archive"));
 		fr_window_batch__extract_here (FR_WINDOW (window), archive, use_progress_dialog);
@@ -334,9 +359,7 @@ handle_method_call (GDBusConnection       *connection,
 
 
 static const GDBusInterfaceVTable interface_vtable = {
-	handle_method_call,
-	NULL, 			/* handle_get_property */
-	NULL 			/* handle_set_property */
+	.method_call = handle_method_call,
 };
 
 
@@ -367,7 +390,7 @@ fr_application_finalize (GObject *object)
 	_g_object_unref (self->listing_settings);
 	_g_object_unref (self->ui_settings);
 
-	release_data ();
+	fr_release_data ();
 
         G_OBJECT_CLASS (fr_application_parent_class)->finalize (object);
 }
@@ -380,7 +403,7 @@ on_bus_acquired_for_archive_manager (GDBusConnection *connection,
 {
 	FrApplication *self = user_data;
 	guint          registration_id;
-	GError        *error = NULL;
+	g_autoptr (GError) error = NULL;
 
 	registration_id = g_dbus_connection_register_object (connection,
 							     "/org/gnome/ArchiveManager1",
@@ -391,7 +414,6 @@ on_bus_acquired_for_archive_manager (GDBusConnection *connection,
 							     &error); /* GError** */
 	if (registration_id == 0) {
 		g_error ("%s", error->message);
-		g_clear_error (&error);
 	}
 }
 
@@ -457,13 +479,8 @@ fr_application_startup (GApplication *application)
 	g_set_application_name (_("Archive Manager"));
 	gtk_window_set_default_icon_name ("org.gnome.ArchiveManager");
 
-#ifdef ENABLE_NOTIFICATION
-	if (! notify_init (g_get_application_name ()))
-                g_warning ("Cannot initialize notification system.");
-#endif /* ENABLE_NOTIFICATION */
-
 	fr_application_register_archive_manager_service (FR_APPLICATION (application));
-	initialize_data ();
+	fr_initialize_data ();
 
 	/* use the menubar only when the shell shows the menu bar */
 
@@ -477,9 +494,13 @@ fr_application_startup (GApplication *application)
 					    HDY_COLOR_SCHEME_PREFER_LIGHT);
 
 	if (shell_shows_menubar)
-		initialize_app_menubar (application);
+		fr_initialize_app_menubar (application);
 	else
-		initialize_app_menu (application);
+		fr_initialize_app_menu (application);
+
+	/* Setup actions */
+	g_action_map_add_action_entries (G_ACTION_MAP (application), entries,
+					 G_N_ELEMENTS (entries), NULL);
 }
 
 
