@@ -23,7 +23,7 @@
 #define FR_ARCHIVE_H
 
 #include <glib.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "typedefs.h"
 
 typedef enum {
@@ -63,19 +63,17 @@ extern char *action_names[];
 
 typedef struct _FrArchive         FrArchive;
 typedef struct _FrArchiveClass    FrArchiveClass;
-typedef struct _FrArchivePrivate  FrArchivePrivate;
 
-typedef gboolean (*FakeLoadFunc) (FrArchive *archive, gpointer data);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (FrArchive, g_object_unref)
 
 struct _FrArchive {
 	GObject  __parent;
-	FrArchivePrivate *priv;
 
 	/*<public, read only>*/
 
 	const char    *mime_type;
-	GPtrArray     *files;                      /* Array of FileData */
-	GHashTable    *files_hash;                 /* Hash of FileData with original_path as key */
+	GPtrArray     *files;                      /* Array of FrFileData */
+	GHashTable    *files_hash;                 /* Hash of FrFileData with original_path as key */
 	int            n_regular_files;
 
 	/*<public>*/
@@ -248,7 +246,7 @@ struct _FrArchiveClass {
 	/*< virtual functions >*/
 
 	const char ** (*get_mime_types)    (FrArchive           *archive);
-	FrArchiveCap  (*get_capabilities)  (FrArchive           *archive,
+	FrArchiveCaps  (*get_capabilities)  (FrArchive           *archive,
 					    const char          *mime_type,
 					    gboolean             check_command);
 	void          (*set_mime_type)     (FrArchive           *archive,
@@ -347,12 +345,22 @@ struct _FrArchiveClass {
 };
 
 GType         fr_archive_get_type                (void);
+
+/**
+ * fr_archive_get_file:
+ * Returns: (transfer none)
+ */
 GFile *       fr_archive_get_file                (FrArchive           *archive);
 gboolean      fr_archive_is_capable_of           (FrArchive           *archive,
 						  FrArchiveCaps        capabilities);
+
+/**
+ * fr_archive_get_supported_types:
+ * Returns: (transfer none)
+ */
 const char ** fr_archive_get_supported_types     (FrArchive           *archive);
 void          fr_archive_update_capabilities     (FrArchive           *archive);
-FrArchiveCap  fr_archive_get_capabilities        (FrArchive           *archive,
+FrArchiveCaps  fr_archive_get_capabilities        (FrArchive           *archive,
 						  const char          *mime_type,
 						  gboolean             check_command);
 void          fr_archive_set_mime_type           (FrArchive           *archive,
@@ -362,12 +370,22 @@ const char *  fr_archive_get_packages            (FrArchive           *archive,
 						  const char          *mime_type);
 void          fr_archive_set_stoppable           (FrArchive           *archive,
 						  gboolean             stoppable);
+
+/**
+ * fr_archive_create:
+ * Returns: (transfer full)
+ */
 FrArchive *   fr_archive_create                  (GFile               *file,
 						  const char          *mime_type);
 void          fr_archive_open                    (GFile               *file,
 		       	       	       	          GCancellable        *cancellable,
 		       	       	       	          GAsyncReadyCallback  callback,
 		       	       	       	          gpointer             user_data);
+
+/**
+ * fr_archive_open_finish:
+ * Returns: (transfer full)
+ */
 FrArchive *   fr_archive_open_finish             (GFile               *file,
 						  GAsyncResult        *result,
 						  GError             **error);
@@ -379,8 +397,13 @@ void          fr_archive_list                    (FrArchive           *archive,
 gboolean      fr_archive_operation_finish        (FrArchive           *archive,
 						  GAsyncResult        *result,
 						  GError             **error);
+
+/**
+ * fr_archive_add_files:
+ * @file_list: (element-type GFile)
+ */
 void          fr_archive_add_files               (FrArchive           *archive,
-						  GList               *file_list, /* GFile list */
+						  GList               *file_list,
 						  GFile               *base_dir,
 						  const char          *dest_dir,
 						  gboolean             update,
@@ -392,8 +415,13 @@ void          fr_archive_add_files               (FrArchive           *archive,
 						  GCancellable        *cancellable,
 						  GAsyncReadyCallback  callback,
 						  gpointer             user_data);
+
+/**
+ * fr_archive_add_files_with_filter:
+ * @file_list: (element-type GFile)
+ */
 void          fr_archive_add_files_with_filter   (FrArchive           *archive,
-						  GList               *file_list, /* GFile list */
+						  GList               *file_list,
 						  GFile               *base_dir,
 						  const char          *include_files,
 						  const char          *exclude_files,
@@ -408,12 +436,22 @@ void          fr_archive_add_files_with_filter   (FrArchive           *archive,
 						  GCancellable        *cancellable,
 						  GAsyncReadyCallback  callback,
 						  gpointer             user_data);
+
+/**
+ * fr_archive_remove:
+ * @file_list: (element-type GFile)
+ */
 void          fr_archive_remove                  (FrArchive           *archive,
 						  GList               *file_list,
 						  FrCompression        compression,
 						  GCancellable        *cancellable,
 						  GAsyncReadyCallback  callback,
 						  gpointer             user_data);
+
+/**
+ * fr_archive_extract:
+ * @file_list: (element-type GFile)
+ */
 void          fr_archive_extract                 (FrArchive           *archive,
 						  GList               *file_list,
 						  GFile               *destination,
@@ -436,6 +474,11 @@ gboolean      fr_archive_extract_here            (FrArchive           *archive,
 void          fr_archive_set_last_extraction_destination
 						 (FrArchive           *archive,
 						  GFile               *folder);
+
+/**
+ * fr_archive_get_last_extraction_destination:
+ * Returns: (transfer none)
+ */
 GFile *       fr_archive_get_last_extraction_destination
 						 (FrArchive           *archive);
 void          fr_archive_test                    (FrArchive           *archive,
@@ -443,6 +486,11 @@ void          fr_archive_test                    (FrArchive           *archive,
 		       	       	       	          GCancellable        *cancellable,
 		       	       	       	          GAsyncReadyCallback  callback,
 		       	       	       	          gpointer             user_data);
+
+/**
+ * fr_archive_rename:
+ * @file_list: (element-type GFile)
+ */
 void          fr_archive_rename                  (FrArchive           *archive,
 						  GList               *file_list,
 						  const char          *old_name,
@@ -454,6 +502,11 @@ void          fr_archive_rename                  (FrArchive           *archive,
 						  GCancellable        *cancellable,
 						  GAsyncReadyCallback  callback,
 						  gpointer             user_data);
+
+/**
+ * fr_archive_paste_clipboard:
+ * @files: (element-type GFile)
+ */
 void          fr_archive_paste_clipboard         (FrArchive           *archive,
 						  GFile               *file,
 						  char                *password,
@@ -468,6 +521,11 @@ void          fr_archive_paste_clipboard         (FrArchive           *archive,
 		       	       	       	          GCancellable        *cancellable,
 		       	       	       	          GAsyncReadyCallback  callback,
 		       	       	       	          gpointer             user_data);
+
+/**
+ * fr_archive_add_dropped_items:
+ * @item_list: (element-type GFile)
+ */
 void          fr_archive_add_dropped_items       (FrArchive           *archive,
 						  GList               *item_list,
 						  const char          *dest_dir,
@@ -478,6 +536,12 @@ void          fr_archive_add_dropped_items       (FrArchive           *archive,
 						  GCancellable        *cancellable,
 						  GAsyncReadyCallback  callback,
 						  gpointer             user_data);
+
+/**
+ * fr_archive_update_open_files:
+ * @file_list: (element-type GFile)
+ * @dir_list: (element-type GFile)
+ */
 void          fr_archive_update_open_files       (FrArchive           *archive,
 						  GList               *file_list,
 						  GList               *dir_list,
@@ -521,7 +585,7 @@ double        fr_archive_progress_inc_completed_bytes
 						  gsize                new_completed);
 double        fr_archive_progress_get_fraction   (FrArchive           *archive);
 void          fr_archive_add_file                (FrArchive           *archive,
-						  FileData            *file_data);
+						  FrFileData *file_data);
 
 /* utilities */
 
