@@ -26,7 +26,7 @@
 #include <time.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "file-utils.h"
 #include "glib-utils.h"
 #include "fr-command.h"
@@ -38,7 +38,7 @@ struct _FrCommand7z
 {
 	FrCommand  parent_instance;
 	gboolean   list_started;
-	FileData  *fdata;
+	FrFileData *fdata;
 };
 
 
@@ -91,7 +91,7 @@ list__process_line (char     *line,
 	FrCommand7z  *self = FR_COMMAND_7Z (data);
 	FrArchive    *archive = FR_ARCHIVE (data);
 	char        **fields;
-	FileData     *fdata;
+	FrFileData *fdata;
 
 	g_return_if_fail (line != NULL);
 
@@ -109,7 +109,7 @@ list__process_line (char     *line,
 	if (strcmp (line, "") == 0) {
 		if (self->fdata != NULL) {
 			if (self->fdata->original_path == NULL) {
-				file_data_free (self->fdata);
+				fr_file_data_free (self->fdata);
 				self->fdata = NULL;
 			}
 			else {
@@ -127,7 +127,7 @@ list__process_line (char     *line,
 	}
 
 	if (self->fdata == NULL)
-		self->fdata = file_data_new ();
+		self->fdata = fr_file_data_new ();
 
 	fields = g_strsplit (line, " = ", 2);
 
@@ -179,7 +179,15 @@ list__process_line (char     *line,
 static void
 fr_command_7z_begin_command (FrCommand *comm)
 {
-	if (_g_program_is_in_path ("7z"))
+	// Modern 7-Zip by the original author.
+	// Statically linked from a binary distribution, almost guaranteed to work.
+	if (_g_program_is_in_path ("7zzs"))
+		fr_process_begin_command (comm->process, "7zzs");
+	// Dynamically linked from either binary or source distribution.
+	else if (_g_program_is_in_path ("7zz"))
+		fr_process_begin_command (comm->process, "7zz");
+	// Legacy p7zip project.
+	else if (_g_program_is_in_path ("7z"))
 		fr_process_begin_command (comm->process, "7z");
 	else if (_g_program_is_in_path ("7za"))
 		fr_process_begin_command (comm->process, "7za");
@@ -209,7 +217,7 @@ list__begin (gpointer data)
 	FrCommand7z *p7z_comm = data;
 
 	if (p7z_comm->fdata != NULL) {
-		file_data_free (p7z_comm->fdata);
+		fr_file_data_free (p7z_comm->fdata);
 		p7z_comm->fdata = NULL;
 	}
 	p7z_comm->list_started = FALSE;
@@ -519,7 +527,7 @@ fr_command_7z_handle_error (FrCommand *command,
 	FrArchive *archive = FR_ARCHIVE (command);
 
 	if (error->type == FR_ERROR_NONE) {
-		FileData *first;
+		FrFileData *first;
 		char     *basename;
 		char     *testname;
 
@@ -568,6 +576,7 @@ fr_command_7z_handle_error (FrCommand *command,
 const char *sevenz_mime_types[] = {
 	"application/epub+zip",
 	"application/x-7z-compressed",
+	"application/x-apple-diskimage",
 	"application/x-arj",
 	"application/vnd.ms-cab-compressed",
 	"application/x-cd-image",
@@ -589,48 +598,122 @@ fr_command_7z_get_mime_types (FrArchive *archive)
 }
 
 
-static FrArchiveCap
+static gboolean
+check_info_subcommand_for_codec_support (char *program_name, char *codec_name) {
+	if (! _g_program_is_in_path (program_name)) {
+		return FALSE;
+	}
+
+	g_autofree gchar *standard_output = NULL;
+
+	gchar* argv[] = {
+		program_name,
+		"i",
+		NULL
+	};
+	if (!g_spawn_sync (
+		/* working_directory = */ NULL,
+		argv,
+		/* envp = */ NULL,
+		G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
+		/* child_setup = */ NULL,
+		/* user_data = */ NULL,
+		&standard_output,
+		/* standard_error = */ NULL,
+		/* wait_status = */ NULL,
+		/* error = */ NULL
+	)) {
+		return FALSE;
+	}
+
+	gchar *codecs = g_strrstr (standard_output, "Codecs:");
+
+	if (codecs == NULL) {
+		return FALSE;
+	}
+
+	gchar *codec_found = g_strrstr (codecs, codec_name);
+
+	return codec_found != NULL;
+}
+
+
+static gboolean
+has_rar_support (gboolean check_command)
+{
+	/*
+	 * Some 7-Zip distributions store RAR codec as a separate shared library and we can detect that.
+	 * Most commonly, however, the programs link the codec statically so the only way to find out is to query them.
+	 */
+	return !check_command
+	       || g_file_test ("/usr/lib/p7zip/Codecs/Rar.so", G_FILE_TEST_EXISTS)
+	       || check_info_subcommand_for_codec_support ("7zzs", "Rar3")
+	       || check_info_subcommand_for_codec_support ("7zz", "Rar3");
+}
+
+
+static FrArchiveCaps
 fr_command_7z_get_capabilities (FrArchive  *archive,
 				const char *mime_type,
 				gboolean    check_command)
 {
-	FrArchiveCap capabilities;
+	FrArchiveCaps capabilities;
 
 	capabilities = FR_ARCHIVE_CAN_STORE_MANY_FILES;
-	if (! _g_program_is_available ("7za", check_command) && ! _g_program_is_available ("7zr", check_command) && ! _g_program_is_available ("7z", check_command))
+	/*
+	 * We support two sets of program names:
+	 * - 7z/7za/7zr from the no longer maintained p7zip project
+	 * - 7zz/7zzs from the 7-Zip project by the original author
+	 * Their CLI is mostly compatible.
+	 */
+
+	// Support full range of formats (except possibly rar).
+	gboolean available_7zip = _g_program_is_available ("7zzs", check_command) || _g_program_is_available ("7zz", check_command);
+	gboolean available_p7zip_full = _g_program_is_available ("7z", check_command);
+	gboolean available_formats_full = available_7zip || available_p7zip_full;
+	// Supports 7z, xz, lzma, zip, bzip2, gzip, tar, cab, ppmd and split.
+	gboolean available_p7zip_partial = _g_program_is_available ("7za", check_command);
+	// Supports 7z, xz, lzma and split.
+	gboolean available_p7zip_reduced = _g_program_is_available ("7zr", check_command);
+
+	if (! available_7zip
+	    && ! available_p7zip_full
+	    && ! available_p7zip_partial
+	    && ! available_p7zip_reduced)
 		return capabilities;
 
 	if (_g_mime_type_matches (mime_type, "application/x-7z-compressed")) {
 		capabilities |= FR_ARCHIVE_CAN_READ_WRITE | FR_ARCHIVE_CAN_CREATE_VOLUMES;
-		if (_g_program_is_available ("7z", check_command))
+		if (available_formats_full)
 			capabilities |= FR_ARCHIVE_CAN_ENCRYPT | FR_ARCHIVE_CAN_ENCRYPT_HEADER;
 	}
 	else if (_g_mime_type_matches (mime_type, "application/x-7z-compressed-tar")) {
 		capabilities |= FR_ARCHIVE_CAN_READ_WRITE;
-		if (_g_program_is_available ("7z", check_command))
+		if (available_formats_full)
 			capabilities |= FR_ARCHIVE_CAN_ENCRYPT | FR_ARCHIVE_CAN_ENCRYPT_HEADER;
 	}
-	else if (_g_program_is_available ("7z", check_command)) {
+	else if (available_formats_full) {
 		if (_g_mime_type_matches (mime_type, "application/x-rar")
 		    || _g_mime_type_matches (mime_type, "application/x-cbr"))
 		{
 			/* give priority to rar and unrar that supports RAR files better. */
-			if (!_g_program_is_available ("rar", check_command)
-			    && !_g_program_is_available ("unrar", check_command)
-			    && (! check_command || g_file_test ("/usr/lib/p7zip/Codecs/Rar29.so", G_FILE_TEST_EXISTS)))
+			if (!_g_program_is_available ("rar", TRUE)
+			    && !_g_program_is_available ("unrar", TRUE)
+			    && has_rar_support (check_command))
 				capabilities |= FR_ARCHIVE_CAN_READ;
 		}
 		else
 			capabilities |= FR_ARCHIVE_CAN_READ;
 
-		if (_g_mime_type_matches (mime_type, "application/x-cbz")
+		if (_g_mime_type_matches (mime_type, "application/epub+zip")
+		    || _g_mime_type_matches (mime_type, "application/x-cbz")
 		    || _g_mime_type_matches (mime_type, "application/x-ms-dos-executable")
 		    || _g_mime_type_matches (mime_type, "application/zip"))
 		{
 			capabilities |= FR_ARCHIVE_CAN_WRITE | FR_ARCHIVE_CAN_ENCRYPT;
 		}
 	}
-	else if (_g_program_is_available ("7za", check_command)) {
+	else if (available_p7zip_partial) {
 		if (_g_mime_type_matches (mime_type, "application/vnd.ms-cab-compressed")
 		    || _g_mime_type_matches (mime_type, "application/zip"))
 		{
@@ -654,11 +737,11 @@ fr_command_7z_get_packages (FrArchive  *archive,
 			    const char *mime_type)
 {
 	if (_g_mime_type_matches (mime_type, "application/x-rar"))
-		return PACKAGES ("p7zip,p7zip-rar");
+		return FR_PACKAGES ("7zip,7zip-rar");
 	else if (_g_mime_type_matches (mime_type, "application/zip") || _g_mime_type_matches (mime_type, "application/vnd.ms-cab-compressed"))
-		return PACKAGES ("p7zip,p7zip-full");
+		return FR_PACKAGES ("7zip,7zip-full");
 	else
-		return PACKAGES ("p7zip");
+		return FR_PACKAGES ("7zip");
 }
 
 
