@@ -26,7 +26,7 @@
 #include <time.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "file-utils.h"
 #include "gio-utils.h"
 #include "glib-utils.h"
@@ -44,7 +44,7 @@ struct _FrCommandRar
 	gboolean   rar4_odd_line;
 	gboolean   rar5;
 	gboolean   rar5_30;
-	FileData  *fdata;
+	FrFileData *fdata;
 };
 
 
@@ -199,9 +199,9 @@ parse_name_field (char         *line,
 		  FrCommandRar *rar_comm)
 {
 	char     *name_field;
-	FileData *fdata;
+	FrFileData *fdata;
 
-	rar_comm->fdata = fdata = file_data_new ();
+	rar_comm->fdata = fdata = fr_file_data_new ();
 
 	/* read file name. */
 
@@ -285,7 +285,7 @@ process_line (char     *line,
 		parse_name_field (line, rar_comm);
 
 	if (! rar_comm->rar4_odd_line) {
-		FileData   *fdata;
+		FrFileData *fdata;
 		const char *size_field, *ratio_field, *date_field, *time_field, *attr_field;
 
 		fdata = rar_comm->fdata;
@@ -312,7 +312,7 @@ process_line (char     *line,
 		if (g_strv_length (fields) < 6) {
 			/* wrong line format, treat this line as a filename line */
 			g_strfreev (fields);
-			file_data_free (rar_comm->fdata);
+			fr_file_data_free (rar_comm->fdata);
 			rar_comm->fdata = NULL;
 			rar_comm->rar4_odd_line = TRUE;
 			parse_name_field (line, rar_comm);
@@ -323,7 +323,7 @@ process_line (char     *line,
 			{
 				/* ignore files that span more volumes */
 
-				file_data_free (rar_comm->fdata);
+				fr_file_data_free (rar_comm->fdata);
 				rar_comm->fdata = NULL;
 			}
 			else {
@@ -727,28 +727,19 @@ fr_command_rar_handle_error (FrCommand *comm,
 	if (error->type == FR_ERROR_NONE)
 		return;
 
-	/* ignore warnings */
-	if (error->status <= 1)
+	if (error->status <= 1) {
+		/* ignore warnings */
 		fr_error_clear_gerror (error);
+	}
+	else if (error->status == 11) {
+		/* handle wrong password */
+		fr_error_take_gerror (error, g_error_new_literal (FR_ERROR, FR_ERROR_ASK_PASSWORD, ""));
+		return;
+	}
 
 	for (scan = g_list_last (comm->process->err.raw); scan; scan = scan->prev) {
 		char *line = scan->data;
 
-		if (strstr (line, "password incorrect") != NULL) {
-			fr_error_take_gerror (error, g_error_new_literal (FR_ERROR, FR_ERROR_ASK_PASSWORD, ""));
-			break;
-		}
-
-		if (strstr (line, "password is incorrect") != NULL) {
-			fr_error_take_gerror (error, g_error_new_literal (FR_ERROR, FR_ERROR_ASK_PASSWORD, ""));
-			break;
-		}
-
-		if (strstr (line, "wrong password") != NULL) {
-			fr_error_take_gerror (error, g_error_new_literal (FR_ERROR, FR_ERROR_ASK_PASSWORD, ""));
-			break;
-		}
-
 		if (strncmp (line, "Unexpected end of archive", 25) == 0) {
 			/* FIXME: handle this type of errors at a higher level when the freeze is over. */
 		}
@@ -776,12 +767,12 @@ fr_command_rar_get_mime_types (FrArchive *archive)
 }
 
 
-static FrArchiveCap
+static FrArchiveCaps
 fr_command_rar_get_capabilities (FrArchive  *archive,
 			         const char *mime_type,
 				 gboolean    check_command)
 {
-	FrArchiveCap capabilities;
+	FrArchiveCaps capabilities;
 
 	capabilities = FR_ARCHIVE_CAN_STORE_MANY_FILES | FR_ARCHIVE_CAN_ENCRYPT | FR_ARCHIVE_CAN_ENCRYPT_HEADER;
 	if (_g_program_is_available ("rar", check_command))
@@ -801,7 +792,7 @@ static const char *
 fr_command_rar_get_packages (FrArchive  *archive,
 			     const char *mime_type)
 {
-	return PACKAGES ("rar,unrar");
+	return FR_PACKAGES ("rar,unrar");
 }
 
 
