@@ -105,6 +105,9 @@ struct _FrFileSelectorDialog {
 	GthIconCache  *icon_cache;
 	GSettings     *settings;
 	gboolean       show_hidden;
+	GSimpleActionGroup *action_map;
+	GtkPopover *file_context_menu;
+
 };
 
 
@@ -123,6 +126,8 @@ fr_file_selector_dialog_finalize (GObject *object)
 	g_object_unref (self->builder);
 	_g_object_unref (self->current_folder);
 	g_object_unref (self->settings);
+	g_clear_object (&self->action_map);
+
 
 	G_OBJECT_CLASS (fr_file_selector_dialog_parent_class)->finalize (object);
 }
@@ -477,7 +482,7 @@ _update_sensitivity (FrFileSelectorDialog *self)
 
 static void
 is_selected_cellrenderertoggle_toggled_cb (GtkCellRendererToggle *cell_renderer,
-					   gchar                 *path,
+					   const gchar           *path,
 					   gpointer               user_data)
 {
 	FrFileSelectorDialog *self = user_data;
@@ -556,13 +561,13 @@ go_up_button_clicked_cb (GtkButton *button,
 
 static void
 places_sidebar_open_location_cb (GtkPlacesSidebar  *sidebar,
-				 GObject           *location,
+				 GFile             *location,
 				 GtkPlacesOpenFlags open_flags,
 				 gpointer           user_data)
 {
 	FrFileSelectorDialog *self = user_data;
 
-	fr_file_selector_dialog_set_current_folder (self, G_FILE (location));
+	fr_file_selector_dialog_set_current_folder (self, location);
 }
 
 
@@ -574,7 +579,10 @@ files_treeview_button_press_event_cb (GtkWidget      *widget,
 	FrFileSelectorDialog *self = user_data;
 
 	if (event->button == 3) {
-		gtk_menu_popup_at_pointer (GTK_MENU (GET_WIDGET ("file_list_context_menu")),  (GdkEvent *) event);
+		int wx;
+		int wy;
+		gtk_tree_view_convert_bin_window_to_widget_coords (GTK_TREE_VIEW (widget), event->x, event->y, &wx, &wy);
+		_gtk_popover_popup_at_position (self->file_context_menu, wx, wy);
 
 		return TRUE;
 	}
@@ -600,20 +608,24 @@ select_all_files (FrFileSelectorDialog *self,
 	                            -1);
 	}
 	while (gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &iter));
+
+	_update_sensitivity (self);
 }
 
 
 static void
-select_all_menuitem_activate_cb (GtkMenuItem *menu_item,
-			  	 gpointer     user_data)
+select_all_activate_cb (GSimpleAction *action,
+			  GVariant *state,
+			  gpointer user_data)
 {
 	select_all_files (FR_FILE_SELECTOR_DIALOG (user_data), TRUE);
 }
 
 
 static void
-unselect_all_menuitem_activate_cb (GtkMenuItem *menu_item,
-				   gpointer     user_data)
+unselect_all_activate_cb (GSimpleAction *action,
+				   GVariant *state,
+				    gpointer user_data)
 {
 	select_all_files (FR_FILE_SELECTOR_DIALOG (user_data), FALSE);
 }
@@ -626,31 +638,67 @@ _set_current_folder (FrFileSelectorDialog *self,
 
 
 static void
-show_hidden_files_menuitem_toggled_cb (GtkCheckMenuItem *checkmenuitem,
-				       gpointer          user_data)
+show_hidden_files_toggled_cb (GSimpleAction *action,
+				       GVariant *state,
+				        gpointer user_data)
 {
 	FrFileSelectorDialog *self = user_data;
 	GFile                *folder;
 	GList                *selected_files;
 
-	self->show_hidden = gtk_check_menu_item_get_active (checkmenuitem);
+	self->show_hidden = g_variant_get_boolean (state);
 	folder = fr_file_selector_dialog_get_current_folder (self);
 	selected_files = fr_file_selector_dialog_get_selected_files (self);
 	_set_current_folder (self, folder, selected_files);
 
+	g_simple_action_set_state (action, state);
+
 	_g_object_list_unref (selected_files);
 	_g_object_unref (folder);
 }
 
 
+static void
+activate_toggle (GSimpleAction *action,
+                 GVariant      *parameter,
+                 gpointer       user_data)
+{
+	GVariant *state;
+
+	state = g_action_get_state (G_ACTION (action));
+	g_action_change_state (G_ACTION (action), g_variant_new_boolean (!g_variant_get_boolean (state)));
+	g_variant_unref (state);
+}
+
+
+static GActionEntry dlg_entries[] = {
+	{
+		.name = "select-all",
+		.activate = select_all_activate_cb,
+	},
+	{
+		.name = "deselect-all",
+		.activate = unselect_all_activate_cb,
+	},
+	{
+		.name = "show-hidden",
+		.activate = activate_toggle,
+		.state = "false",
+		.change_state = show_hidden_files_toggled_cb,
+	},
+};
+
+
 static void
 fr_file_selector_dialog_init (FrFileSelectorDialog *self)
 {
 	self->current_folder = NULL;
-	self->builder = _gtk_builder_new_from_resource ("file-selector.ui");
+	self->builder = gtk_builder_new_from_resource (FILE_ROLLER_RESOURCE_UI_PATH "file-selector.ui");
 	self->icon_cache = NULL;
 	self->settings = g_settings_new ("org.gnome.FileRoller.FileSelector");
 	self->show_hidden = g_settings_get_boolean (self->settings, PREF_FILE_SELECTOR_SHOW_HIDDEN);
+	self->action_map = g_simple_action_group_new ();
+	self->file_context_menu = GTK_POPOVER (gtk_popover_new_from_model (GET_WIDGET ("files_treeview"), G_MENU_MODEL (gtk_builder_get_object (self->builder, "file_list_context_menu_model"))));
 
 	gtk_container_set_border_width (GTK_CONTAINER (self), 5);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), GET_WIDGET ("content"), TRUE, TRUE, 0);
@@ -660,40 +708,33 @@ fr_file_selector_dialog_init (FrFileSelectorDialog *self)
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (GET_WIDGET ("files_liststore")), FILE_LIST_COLUMN_MODIFIED, files_modified_column_sort_func, self, NULL);
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (GET_WIDGET ("files_liststore")), FILE_LIST_COLUMN_NAME, GTK_SORT_ASCENDING);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (GET_WIDGET ("show_hidden_files_menuitem")), self->show_hidden);
-
-	g_signal_connect (GET_WIDGET ("is_selected_cellrenderertoggle"),
+	g_signal_connect (GTK_CELL_RENDERER_TOGGLE (GET_WIDGET ("is_selected_cellrenderertoggle")),
 			  "toggled",
 			  G_CALLBACK (is_selected_cellrenderertoggle_toggled_cb),
 			  self);
-	g_signal_connect (GET_WIDGET ("files_treeview"),
+	g_signal_connect (GTK_TREE_VIEW (GET_WIDGET ("files_treeview")),
 			  "row-activated",
 			  G_CALLBACK (files_treeview_row_activated_cb),
 			  self);
-	g_signal_connect (GET_WIDGET ("go_up_button"),
+	g_signal_connect (GTK_BUTTON (GET_WIDGET ("go_up_button")),
 			  "clicked",
 			  G_CALLBACK (go_up_button_clicked_cb),
 			  self);
-	g_signal_connect (GET_WIDGET ("places_sidebar"),
+	g_signal_connect (GTK_PLACES_SIDEBAR (GET_WIDGET ("places_sidebar")),
 			  "open-location",
 			  G_CALLBACK (places_sidebar_open_location_cb),
 			  self);
-	g_signal_connect (GET_WIDGET ("files_treeview"),
+	g_signal_connect (GTK_TREE_VIEW (GET_WIDGET ("files_treeview")),
 			  "button-press-event",
 			  G_CALLBACK (files_treeview_button_press_event_cb),
 			  self);
-	g_signal_connect (GET_WIDGET ("select_all_menuitem"),
-			  "activate",
-			  G_CALLBACK (select_all_menuitem_activate_cb),
-			  self);
-	g_signal_connect (GET_WIDGET ("unselect_all_menuitem"),
-			  "activate",
-			  G_CALLBACK (unselect_all_menuitem_activate_cb),
-			  self);
-	g_signal_connect (GET_WIDGET ("show_hidden_files_menuitem"),
-			  "toggled",
-			  G_CALLBACK (show_hidden_files_menuitem_toggled_cb),
-			  self);
+
+	g_action_map_add_action_entries (G_ACTION_MAP (self->action_map),
+			dlg_entries, G_N_ELEMENTS (dlg_entries),
+			self);
+	gtk_widget_insert_action_group (GTK_WIDGET (self), "file-selector-dialog", G_ACTION_GROUP (self->action_map));
+
+	g_simple_action_set_state (G_SIMPLE_ACTION (g_action_map_lookup_action (G_ACTION_MAP (self->action_map), "show-hidden")), g_variant_new_boolean (self->show_hidden));
 
 	_fr_file_selector_dialog_update_size (self);
 	gtk_widget_grab_focus (GET_WIDGET ("files_treeview"));
@@ -731,6 +772,13 @@ fr_file_selector_dialog_get_extra_widget (FrFileSelectorDialog *self)
 }
 
 
+GSimpleActionGroup *
+fr_file_selector_dialog_get_action_map (FrFileSelectorDialog *self)
+{
+	return self->action_map;
+}
+
+
 static gboolean
 _g_date_time_same_day (GDateTime *dt1,
 		       GDateTime *dt2)
