@@ -87,6 +87,7 @@ fr_new_archive_dialog_unmap (GtkWidget *widget)
 	self = FR_NEW_ARCHIVE_DIALOG (widget);
 
 	g_settings_set_boolean (self->settings, PREF_NEW_ENCRYPT_HEADER, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("encrypt_header_checkbutton"))));
+	g_settings_set_boolean (self->settings, PREF_NEW_EXPAND_OPTIONS, gtk_expander_get_expanded (GTK_EXPANDER (GET_WIDGET ("other_options_expander"))));
 	g_settings_set_int (self->settings, PREF_NEW_VOLUME_SIZE, gtk_spin_button_get_value (GTK_SPIN_BUTTON (GET_WIDGET ("volume_spinbutton"))) * MEGABYTE);
 
 	n_format = get_selected_format (self);
@@ -205,9 +206,7 @@ _fr_new_archive_dialog_construct (FrNewArchiveDialog *self,
 	gtk_window_set_resizable (GTK_WINDOW (self), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (self), 5);
 
-	self->builder = _gtk_builder_new_from_resource ("new-archive-dialog.ui");
-	if (self->builder == NULL)
-		return;
+	self->builder = gtk_builder_new_from_resource (FILE_ROLLER_RESOURCE_UI_PATH "new-archive-dialog.ui");
 
 	_g_object_unref (self->original_file);
 	self->original_file = _g_object_ref (original_file);
@@ -231,7 +230,7 @@ _fr_new_archive_dialog_construct (FrNewArchiveDialog *self,
 	}
 	gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_OK);
 
-	sort_mime_types_by_extension (self->supported_types);
+	fr_sort_mime_types_by_extension (self->supported_types);
 
 	/* Set widgets data. */
 
@@ -250,7 +249,8 @@ _fr_new_archive_dialog_construct (FrNewArchiveDialog *self,
 		folder = _g_file_get_home ();
 	gtk_file_chooser_set_current_folder_file (GTK_FILE_CHOOSER (GET_WIDGET ("parent_filechooserbutton")), folder, NULL);
 
-	gtk_expander_set_expanded (GTK_EXPANDER (GET_WIDGET ("other_options_expander")), FALSE);
+	gtk_expander_set_expanded (GTK_EXPANDER (GET_WIDGET ("other_options_expander")),
+				      g_settings_get_boolean (self->settings, PREF_NEW_EXPAND_OPTIONS));
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("encrypt_header_checkbutton")),
 				      g_settings_get_boolean (self->settings, PREF_NEW_ENCRYPT_HEADER));
@@ -278,19 +278,19 @@ _fr_new_archive_dialog_construct (FrNewArchiveDialog *self,
 
 	/* Set the signals handlers. */
 
-	g_signal_connect (GET_WIDGET ("filename_entry"),
+	g_signal_connect (GTK_ENTRY (GET_WIDGET ("filename_entry")),
 			  "changed",
 			  G_CALLBACK (entry_changed_cb),
 			  self);
-	g_signal_connect (GET_WIDGET ("password_entry"),
+	g_signal_connect (GTK_ENTRY (GET_WIDGET ("password_entry")),
 			  "changed",
 			  G_CALLBACK (entry_changed_cb),
 			  self);
-	g_signal_connect (GET_WIDGET ("volume_checkbutton"),
+	g_signal_connect (GTK_CHECK_BUTTON (GET_WIDGET ("volume_checkbutton")),
 			  "toggled",
 			  G_CALLBACK (volume_toggled_cb),
 			  self);
-	g_signal_connect (GET_WIDGET ("extension_comboboxtext"),
+	g_signal_connect (GTK_COMBO_BOX_TEXT (GET_WIDGET ("extension_comboboxtext")),
 			  "changed",
 			  G_CALLBACK (extension_comboboxtext_changed_cb),
 			  self);
