@@ -70,40 +70,15 @@ typedef enum {
 
 /* -- FrWindow -- */
 
-#define FR_TYPE_WINDOW              (fr_window_get_type ())
-#define FR_WINDOW(obj)              (G_TYPE_CHECK_INSTANCE_CAST ((obj), FR_TYPE_WINDOW, FrWindow))
-#define FR_WINDOW_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), FR_WINDOW_TYPE, FrWindowClass))
-#define FR_IS_WINDOW(obj)           (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FR_TYPE_WINDOW))
-#define FR_IS_WINDOW_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), FR_TYPE_WINDOW))
-#define FR_WINDOW_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), FR_TYPE_WINDOW, FrWindowClass))
+#define FR_TYPE_WINDOW (fr_window_get_type ())
+G_DECLARE_FINAL_TYPE (FrWindow, fr_window, FR, WINDOW, GtkApplicationWindow)
 
-typedef struct _FrWindow        FrWindow;
-typedef struct _FrWindowClass   FrWindowClass;
-typedef struct _FrWindowPrivate FrWindowPrivate;
 
 struct _FrWindow
 {
 	GtkApplicationWindow __parent;
-	FrWindowPrivate *priv;
 	FrArchive *archive;
 };
-
-struct _FrWindowClass
-{
-	GtkApplicationWindowClass __parent_class;
-
-	/*<signals>*/
-
-	void (*archive_loaded) (FrWindow   *window,
-				gboolean    success);
-	void (*progress)       (FrWindow   *window,
-			        double      fraction,
-			        const char *msg);
-	void (*ready)          (FrWindow   *window,
-				GError     *error);
-};
-
-GType           fr_window_get_type                     (void);
 GtkWidget *     fr_window_new                          (void);
 void            fr_window_close                        (FrWindow      *window);
 void            fr_window_set_dialog		       (FrWindow      *window,
@@ -117,18 +92,43 @@ gboolean        fr_window_present_dialog_if_created    (FrWindow      *window,
 gboolean        fr_window_archive_new                  (FrWindow      *window,
 							GFile         *file,
 						        const char    *mime_type);
+
+/**
+ * fr_window_archive_open:
+ * Returns: (transfer none)
+ */
 FrWindow *      fr_window_archive_open                 (FrWindow      *window,
 							GFile         *file,
 						        GtkWindow     *parent);
 void            fr_window_archive_close                (FrWindow      *window);
+
+/**
+ * fr_window_get_archive_file:
+ * Returns: (transfer none)
+ */
 GFile *         fr_window_get_archive_file             (FrWindow      *window);
+
+/**
+ * fr_window_get_archive_file_for_paste:
+ * Returns: (transfer none)
+ */
 GFile *         fr_window_get_archive_file_for_paste   (FrWindow      *window);
 gboolean        fr_window_archive_is_present           (FrWindow      *window);
 void            fr_window_archive_reload               (FrWindow      *window);
+
+/**
+ * fr_window_archive_add_files:
+ * @file_list: (element-type GFile)
+ */
 void            fr_window_archive_add_files            (FrWindow      *window,
 							GList         *file_list, /* GFile list */
 							GFile         *base_dir,
 							gboolean       update);
+
+/**
+ * fr_window_archive_add_with_filter:
+ * @files: (element-type GFile)
+ */
 void            fr_window_archive_add_with_filter      (FrWindow      *window,
 							GList         *files, /* GFile list */
 							GFile         *base_dir,
@@ -138,10 +138,25 @@ void            fr_window_archive_add_with_filter      (FrWindow      *window,
 						        const char    *dest_dir,
 						        gboolean       update,
 						        gboolean       follow_links);
+
+/**
+ * fr_window_archive_add_dropped_items:
+ * @file_list: (element-type GFile)
+ */
 void            fr_window_archive_add_dropped_items    (FrWindow      *window,
 						        GList         *file_list);
+
+/**
+ * fr_window_archive_remove:
+ * @file_list: (element-type GFile)
+ */
 void            fr_window_archive_remove               (FrWindow      *window,
 						        GList         *file_list);
+
+/**
+ * fr_window_archive_extract:
+ * @file_list: (element-type GFile)
+ */
 void            fr_window_archive_extract              (FrWindow      *window,
 						        GList         *file_list,
 						        GFile         *destination,
@@ -196,21 +211,52 @@ void            fr_window_set_list_mode                (FrWindow      *window,
 
 /**/
 
+/**
+ * fr_window_get_file_list_selection:
+ * Returns: (element-type filename) (transfer full)
+ */
 GList *         fr_window_get_file_list_selection      (FrWindow    *window,
 						        gboolean     recursive,
+						        gboolean     include_dirs,
 						        gboolean    *has_dirs);
+
+/**
+ * fr_window_get_file_list_from_path_list:
+ * @path_list: (element-type GtkTreeRowReference)
+ * Returns: (element-type filename) (transfer full)
+ */
 GList *         fr_window_get_file_list_from_path_list (FrWindow    *window,
 						        GList       *path_list,
 						        gboolean    *has_dirs);
+
+/**
+ * fr_window_get_file_list_pattern:
+ * Returns: (element-type filename) (transfer full)
+ */
 GList *         fr_window_get_file_list_pattern        (FrWindow    *window,
 						        const char  *pattern);
 int             fr_window_get_n_selected_files         (FrWindow    *window);
+
+/**
+ * fr_window_get_folder_tree_selection:
+ * Returns: (element-type filename) (transfer full)
+ */
 GList *         fr_window_get_folder_tree_selection    (FrWindow    *window,
 						        gboolean     recursive,
 						        gboolean    *has_dirs);
+
+/**
+ * fr_window_get_selection:
+ * Returns: (element-type filename) (transfer full)
+ */
 GList *         fr_window_get_selection                (FrWindow    *window,
 						        gboolean     from_sidebar,
 						        char       **return_base_dir);
+
+/**
+ * fr_window_get_list_store:
+ * Returns: (transfer none)
+ */
 GtkTreeModel *  fr_window_get_list_store               (FrWindow    *window);
 void            fr_window_find                         (FrWindow    *window,
 							gboolean     active);
@@ -242,15 +288,35 @@ gboolean        fr_window_create_archive_and_continue  (FrWindow   *window,
 void            fr_window_action_save_as               (FrWindow   *window);
 void            fr_window_view_last_output             (FrWindow   *window,
 						        const char *title);
+
+/**
+ * fr_window_open_files:
+ * @file_list: (element-type GFile)
+ */
 void            fr_window_open_files                   (FrWindow   *window,
 						        GList      *file_list,
 						        gboolean    ask_application);
+
+/**
+ * fr_window_open_files_with_command:
+ * @file_list: (element-type GFile)
+ */
 void            fr_window_open_files_with_command      (FrWindow   *window,
 						        GList      *file_list,
 						        char       *command);
+
+/**
+ * fr_window_open_files_with_application:
+ * @file_list: (element-type GFile)
+ */
 void            fr_window_open_files_with_application  (FrWindow   *window,
 						        GList      *file_list,
 						        GAppInfo   *app);
+
+/**
+ * fr_window_update_files:
+ * @file_list: (element-type GFile)
+ */
 gboolean        fr_window_update_files                 (FrWindow   *window,
 						        GList      *file_list);
 void            fr_window_update_history_list          (FrWindow   *window);
@@ -259,12 +325,27 @@ void            fr_window_set_default_dir              (FrWindow   *window,
 						        gboolean    freeze);
 void            fr_window_set_open_default_dir         (FrWindow   *window,
 							GFile      *default_dir);
+
+/**
+ * fr_window_get_open_default_dir:
+ * Returns: (transfer none)
+ */
 GFile *         fr_window_get_open_default_dir         (FrWindow   *window);
 void            fr_window_set_add_default_dir          (FrWindow   *window,
 							GFile      *default_dir);
+
+/**
+ * fr_window_get_add_default_dir:
+ * Returns: (transfer none)
+ */
 GFile *         fr_window_get_add_default_dir          (FrWindow   *window);
 void            fr_window_set_extract_default_dir      (FrWindow   *window,
 							GFile      *default_dir);
+
+/**
+ * fr_window_get_extract_default_dir:
+ * Returns: (transfer none)
+ */
 GFile *         fr_window_get_extract_default_dir      (FrWindow   *window);
 void            fr_window_set_folders_visibility       (FrWindow   *window,
 						        gboolean    value);
@@ -273,6 +354,10 @@ void            fr_window_use_progress_dialog          (FrWindow   *window,
 
 /* batch mode procedures. */
 
+/**
+ * fr_window_set_current_action:
+ * @free_func: (scope async) (allow-none): Function used to free the data when the action is removed.
+ */
 void            fr_window_set_current_action  	       (FrWindow      *window,
 						        FrBatchActionType
 								       action,
@@ -284,11 +369,21 @@ void            fr_window_restart_current_action       (FrWindow      *window);
 void            fr_window_batch_new                    (FrWindow      *window,
 						        const char    *title);
 const char *    fr_window_batch_get_title              (FrWindow      *window);
+
+/**
+ * fr_window_batch_append_action:
+ * @free_func: (scope async) (allow-none): Function used to free the data when the action is removed.
+ */
 void            fr_window_batch_append_action          (FrWindow      *window,
 						        FrBatchActionType
 						        	       action,
 						        void          *data,
 						        GFreeFunc      free_func);
+
+/**
+ * fr_window_batch_replace_current_action:
+ * @free_func: (scope async) (allow-none): Function used to free the data when the action is removed.
+ */
 void            fr_window_batch_replace_current_action (FrWindow      *window,
 							FrBatchActionType
 								       action,
@@ -311,6 +406,11 @@ void            fr_window_batch__extract               (FrWindow      *window,
 void            fr_window_batch__extract_here          (FrWindow      *window,
 							GFile         *archive,
 							gboolean       ask_to_open_destination);
+
+/**
+ * fr_window_batch__add_files:
+ * @file_list: (element-type GFile)
+ */
 void            fr_window_batch__add_files             (FrWindow      *window,
 							GFile         *archive,
 						        GList         *file_list);
@@ -320,6 +420,10 @@ void            fr_window_set_notify                   (FrWindow      *window,
 
 /**/
 
+/**
+ * fr_window_file_list_drag_data_get:
+ * @path_list: (element-type GtkTreeRowReference)
+ */
 gboolean        fr_window_file_list_drag_data_get      (FrWindow         *window,
 						        GdkDragContext   *context,
 						        GtkSelectionData *selection_data,
@@ -327,6 +431,11 @@ gboolean        fr_window_file_list_drag_data_get      (FrWindow         *window
 void            fr_window_update_dialog_closed         (FrWindow         *window);
 void		fr_window_dnd_extraction_finished      (FrWindow	 *window,
 							gboolean	  error);
+
+/**
+ * fr_window_extract_archive_and_continue:
+ * @file_list: (element-type GFile)
+ */
 void            fr_window_extract_archive_and_continue (FrWindow   *window,
 							GList      *file_list,
 							GFile      *destination,
