@@ -61,8 +61,7 @@ file_info_free (FileInfo *file_info)
 void
 file_info_list_free (GList *list)
 {
-	g_list_foreach (list, (GFunc) file_info_free, NULL);
-	g_list_free (list);
+	g_list_free_full (list, (GDestroyNotify) file_info_free);
 }
 
 
@@ -185,8 +184,7 @@ for_each_child_data_free (ForEachChildData *fec)
 	_g_info_data_freev (&(fec->current));
 	g_free (fec->attributes);
 	if (fec->to_visit != NULL) {
-		g_list_foreach (fec->to_visit, (GFunc) file_info_free, NULL);
-		g_list_free (fec->to_visit);
+		g_list_free_full (fec->to_visit, (GDestroyNotify) file_info_free);
 	}
 	_g_object_unref (fec->cancellable);
 	g_free (fec);
@@ -808,9 +806,9 @@ g_copy_files_ready_cb (GObject      *source_object,
 
 
 static void
-g_copy_files_progess_cb (goffset  current_num_bytes,
-                         goffset  total_num_bytes,
-                         gpointer user_data)
+g_copy_files_progress_cb (goffset  current_num_bytes,
+                          goffset  total_num_bytes,
+                          gpointer user_data)
 {
 	CopyFilesData *cfd = user_data;
 
@@ -840,7 +838,7 @@ g_copy_current_file (CopyFilesData *cfd)
 			   cfd->flags,
 			   cfd->io_priority,
 			   cfd->cancellable,
-			   g_copy_files_progess_cb,
+			   g_copy_files_progress_cb,
 			   cfd,
 			   g_copy_files_ready_cb,
 			   cfd);
@@ -905,69 +903,6 @@ g_copy_file_async (GFile                 *source,
 }
 
 
-void
-g_copy_uris_async (GList                 *sources,
-		   GList                 *destinations,
-		   GFileCopyFlags         flags,
-		   int                    io_priority,
-		   GCancellable          *cancellable,
-		   CopyProgressCallback   progress_callback,
-		   gpointer               progress_callback_data,
-		   CopyDoneCallback       callback,
-		   gpointer               user_data)
-{
-	GList *source_files, *destination_files;
-
-	source_files = _g_file_list_new_from_uri_list (sources);
-	destination_files = _g_file_list_new_from_uri_list (destinations);
-
-	g_copy_files_async (source_files,
-			    destination_files,
-			    flags,
-			    io_priority,
-			    cancellable,
-			    progress_callback,
-			    progress_callback_data,
-			    callback,
-			    user_data);
-
-	_g_file_list_free (source_files);
-	_g_file_list_free (destination_files);
-}
-
-
-void
-g_copy_uri_async (const char            *source,
-		  const char            *destination,
-		  GFileCopyFlags         flags,
-		  int                    io_priority,
-		  GCancellable          *cancellable,
-		  CopyProgressCallback   progress_callback,
-		  gpointer               progress_callback_data,
-		  CopyDoneCallback       callback,
-		  gpointer               user_data)
-{
-	GList *source_list;
-	GList *destination_list;
-
-	source_list = g_list_append (NULL, (gpointer)source);
-	destination_list = g_list_append (NULL, (gpointer)destination);
-
-	g_copy_uris_async (source_list,
-			   destination_list,
-			   flags,
-			   io_priority,
-			   cancellable,
-			   progress_callback,
-			   progress_callback_data,
-			   callback,
-			   user_data);
-
-	g_list_free (source_list);
-	g_list_free (destination_list);
-}
-
-
 /* -- g_directory_copy_async -- */
 
 
@@ -1010,8 +945,7 @@ directory_copy_data_free (DirectoryCopyData *dcd)
 		g_object_unref (dcd->current_destination);
 		dcd->current_destination = NULL;
 	}
-	g_list_foreach (dcd->to_copy, (GFunc) file_info_free, NULL);
-	g_list_free (dcd->to_copy);
+	g_list_free_full (dcd->to_copy, (GDestroyNotify) file_info_free);
 	g_free (dcd);
 }
 
@@ -1087,9 +1021,9 @@ g_directory_copy_child_done_cb (GObject      *source_object,
 
 
 static void
-g_directory_copy_child_progess_cb (goffset  current_num_bytes,
-                           	   goffset  total_num_bytes,
-                           	   gpointer user_data)
+g_directory_copy_child_progress_cb (goffset  current_num_bytes,
+                                    goffset  total_num_bytes,
+                                    gpointer user_data)
 {
 	DirectoryCopyData *dcd = user_data;
 
@@ -1177,7 +1111,7 @@ g_directory_copy_current_child (DirectoryCopyData *dcd)
 				   dcd->flags,
 				   dcd->io_priority,
 				   dcd->cancellable,
-				   g_directory_copy_child_progess_cb,
+				   g_directory_copy_child_progress_cb,
 				   dcd,
 				   g_directory_copy_child_done_cb,
 				   dcd);
