@@ -40,7 +40,6 @@ typedef struct {
 	const char *accelerator;
 } FrAccelerator;
 
-int           _gtk_tree_selection_count_selected   (GtkTreeSelection *selection);
 GtkWidget *   _gtk_message_dialog_new              (GtkWindow        *parent,
 						    GtkDialogFlags    flags,
 						    const char       *message,
@@ -69,25 +68,11 @@ void          _gtk_dialog_add_to_window_group      (GtkDialog        *dialog);
 void          _gtk_entry_set_locale_text           (GtkEntry         *entry,
 					     	    const char       *text);
 char *        _gtk_entry_get_locale_text           (GtkEntry         *entry);
-void          _gtk_label_set_locale_text           (GtkLabel         *label,
-						    const char       *text);
-char *        _gtk_label_get_locale_text           (GtkLabel         *label);
-void          _gtk_entry_set_filename_text         (GtkEntry         *entry,
-						    const char       *text);
-char *        _gtk_entry_get_filename_text         (GtkEntry         *entry);
-void          _gtk_label_set_filename_text         (GtkLabel         *label,
-						    const char       *text);
-char *        _gtk_label_get_filename_text         (GtkLabel         *label);
 GdkPixbuf *   _g_icon_get_pixbuf                   (GIcon            *icon,
 						    int               size,
 						    GtkIconTheme     *icon_theme);
-GdkPixbuf *   _g_mime_type_get_icon                (const char       *mime_type,
-						    int               icon_size,
-						    GtkIconTheme     *icon_theme);
 void          _gtk_show_help_dialog                (GtkWindow        *parent,
 						    const char       *section);
-GtkBuilder *  _gtk_builder_new_from_file           (const char       *filename);
-GtkBuilder *  _gtk_builder_new_from_resource       (const char       *resource_path);
 GtkWidget *   _gtk_builder_get_widget              (GtkBuilder       *builder,
 						    const char       *name);
 int           _gtk_widget_lookup_for_size          (GtkWidget        *widget,
@@ -105,15 +90,11 @@ GtkWidget *   _gtk_header_bar_create_image_toggle_button
 						   (const char       *icon_name,
 						    const char       *tooltip,
 						    const char       *action_name);
-void          _gtk_window_add_accelerator_for_action
-						   (GtkWindow	     *window,
-						    GtkAccelGroup    *accel_group,
-						    const char       *action_name,
+void          _gtk_add_accelerator_for_action
+						   (const char       *action_name,
 						    const char       *accel,
 						    GVariant         *target);
-void          _gtk_window_add_accelerators_from_menu
-						   (GtkWindow        *window,
-						    GMenuModel       *menu);
+void          _gtk_add_accelerators_from_menu (GMenuModel       *menu);
 gboolean      _gtk_settings_get_dialogs_use_header (void);
 void          _gtk_application_add_accelerator_for_action
 						   (GtkApplication   *app,
@@ -122,5 +103,7 @@ void          _gtk_application_add_accelerator_for_action
 void	      _gtk_application_add_accelerators    (GtkApplication   *app,
 						    const FrAccelerator *accelerators,
 						    int               n_accelerators);
+void	      _gtk_popover_popup_at_selected (GtkPopover *popover, GtkTreeView *view);
+void	      _gtk_popover_popup_at_position (GtkPopover *popover, gdouble x, gdouble y);
 
 #endif
